#
# spec file
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?tmpfiles_create:%global tmpfiles_create systemd-tmpfiles --create}
# baseversion - version of kubernetes for this package
%define baseversion 1.19
%define baseversionminus1 1.18

Name:           kubernetes%{baseversion}
Version:        1.19.15
Release:        lp156.3.19
Summary:        Container Scheduling and Management
License:        Apache-2.0
Group:          System/Management
URL:            https://kubernetes.io/
Source:         kubernetes-%{version}.tar.xz
Source2:        genmanpages.sh
Source3:        kubelet.sh
#systemd services
Source10:       kubelet.service
#config files
Source22:       sysconfig.kubelet-kubernetes
Source23:       kubeadm.conf
Source24:       90-kubeadm.conf
Source25:       10-kubeadm.conf
Source27:       kubelet.tmp.conf
Source28:       kubernetes-rpmlintrc
Source29:       kubernetes.obsinfo
# Patch to change the default registry to registry.opensuse.org/kubic
Patch2:         kubeadm-opensuse-registry.patch
# Patch to change the version check server to kubic.opensuse.org
Patch3:         opensuse-version-checks.patch
# Patch to change the default flexvolume path in kubeadm to match that used by our kubelet, else kubeadm tries to write to /usr when kubelet is already looking at a path on /var thanks to the fix to bsc#1084766
Patch4:         kubeadm-opensuse-flexvolume.patch
BuildRequires:  bash-completion
BuildRequires:  fdupes
BuildRequires:  git
BuildRequires:  go-go-md2man
# Kubernetes 1.19.14 requires at least go 1.15.15 (see changelog)
BuildRequires:  go >= 1.15.15
BuildRequires:  golang-packaging
BuildRequires:  rsync
BuildRequires:  systemd-rpm-macros
BuildRequires:  golang(API) = 1.15
BuildRequires:  golang(github.com/jteeuwen/go-bindata)
ExcludeArch:    %{ix86} s390 ppc64

%description
Kubernetes is a system for automating deployment, scaling, and
management of containerized applications.

It groups containers that make up an application into logical units
for management and discovery.





# packages to build containerized control plane

%package apiserver
Summary:        Kubernetes apiserver for container image
Group:          System/Management
Provides:       kubernetes-apiserver-provider = %{version}
Conflicts:      kubernetes-apiserver-provider

%description apiserver
This subpackage contains the kube-apiserver binary for Kubic images

%package controller-manager
Summary:        Kubernetes controller-manager for container image
Group:          System/Management
Provides:       kubernetes-controller-manager-provider = %{version}
Conflicts:      kubernetes-controller-manager-provider

%description controller-manager
This subpackage contains the kube-controller-manager binary for Kubic images

%package scheduler
Summary:        Kubernetes scheduler for container image
Group:          System/Management
Provides:       kubernetes-scheduler-provider = %{version}
Conflicts:      kubernetes-scheduler-provider

%description scheduler
This subpackage contains the kube-scheduler binary for Kubic images

%package proxy
Summary:        Kubernetes proxy for container image
Group:          System/Management
Provides:       kubernetes-proxy-provider = %{version}
Conflicts:      kubernetes-proxy-provider
Requires:       conntrack-tools
Requires:       ebtables
Requires:       ipset
Requires:       iptables

%description proxy
This subpackage contains the kube-proxy binary for Kubic images

%package kubelet
Summary:        Kubernetes kubelet daemon
Group:          System/Management
Requires:       cri-runtime
Requires:       kubernetes-kubelet-common
Provides:       kubernetes-kubelet%{baseversion} = %{version}
Obsoletes:      kubernetes-kubelet%{baseversion} < %{version}
%{?systemd_requires}

%description kubelet
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubelet daemon (current version)

%package kubelet-common
Summary:        Kubernetes kubelet daemon
Group:          System/Management
Requires:       cri-runtime
Requires:       kubernetes-kubelet%{baseversion}
Provides:       kubernetes-kubelet-common = %{version}
Conflicts:      kubernetes-kubelet-common

%description kubelet-common
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubelet daemon

%package kubeadm
Summary:        Kubernetes kubeadm bootstrapping tool
Group:          System/Management
Provides:       kubernetes-kubeadm-provider = %{version}
Conflicts:      kubernetes-kubeadm-provider
Obsoletes:      kubernetes%{baseversionminus1}-kubeadm
Requires:       cri-runtime
Requires:       ebtables
Requires:       ethtool
Requires:       kubernetes-kubeadm-criconfig
Requires:       socat
Requires(pre):  shadow
Requires:       (kubernetes%{baseversion}-kubelet or kubernetes%{baseversionminus1}-kubelet)

%description kubeadm
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubeadm bootstrapping tool

%package client
Summary:        Kubernetes client tools
Group:          System/Management
Provides:       kubernetes-client-provider = %{version}
Requires:       kubernetes-client-common >= %{version}
Requires(post): update-alternatives
Requires(postun):update-alternatives

%description client
Kubernetes client tools like kubectl.

%package client-common
Summary:        Kubernetes client tools common files
Group:          System/Management
Requires:       kubernetes%{baseversion}-client
Provides:       kubernetes-client-common = %{version}
Conflicts:      kubernetes-client-common
Recommends:     bash-completion

%description client-common
Kubernetes client tools common files

%prep
%setup -q -n kubernetes-%{version}
%patch2 -p0
%patch3 -p1
%patch4 -p0

%build
# This is fixing bug bsc#1065972
export KUBE_GIT_COMMIT=$(grep "commit:" %{SOURCE29} | cut -d ":" -f2 | tr -d " ")
# KUBE_GIT_TREE_STATE="clean" indicates no changes since the git commit id
# KUBE_GIT_TREE_STATE="dirty" indicates source code changes after the git commit id
export KUBE_GIT_TREE_STATE="clean"
export KUBE_GIT_VERSION=v%{version}

# https://bugzilla.redhat.com/show_bug.cgi?id=1392922#c1
%ifarch ppc64le
export GOLDFLAGS='-linkmode=external'
%endif

#TEST
make WHAT="cmd/kube-apiserver cmd/kube-controller-manager cmd/kube-scheduler cmd/kube-proxy cmd/kubelet cmd/kubectl cmd/kubeadm" GOFLAGS="-buildmode=pie"

# The majority of the documentation has already been moved into
# http://kubernetes.io/docs/admin, and most of the files stored in the `docs`
# directory simply point there. That being said, some of the files are actual
# man pages, but they have to be generated with `hack/generate-docs.sh`. So,
# let's do that and run `genmanpages.sh`.
./hack/generate-docs.sh || true
pushd docs
pushd admin
cp kube-apiserver.md kube-controller-manager.md kube-proxy.md kube-scheduler.md kubelet.md ..
popd
cp %{SOURCE2} genmanpages.sh
bash genmanpages.sh
popd

%install

%ifarch ppc64le aarch64
output_path="_output/local/go/bin"
%else
output_path="_output/local/bin/linux/%{go_arch}"
%endif

install -m 755 -d %{buildroot}%{_bindir}

echo "+++ INSTALLING kubeadm"
install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/kubeadm

binaries=(kube-apiserver kube-controller-manager kube-scheduler kube-proxy)
for bin in "${binaries[@]}"; do
  echo "+++ INSTALLING ${bin}"
  install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/${bin}
done

for bin in kubelet kubectl; do
  echo "+++ INSTALLING ${bin} with %{baseversion} suffix"
  install -p -m 755 ${output_path}/${bin} %{buildroot}%{_bindir}/${bin}%{baseversion}
done

echo "+++ INSTALLING kubelet multi-version loader"
install -p -m 755 %{SOURCE3} %{buildroot}%{_bindir}/kubelet

# create sysconfig.kubelet-kubernetes in fullupdir
sed -i -e 's|BASE_VERSION|%{baseversion}|g' %{SOURCE22}
install -D -m 0644 %{SOURCE22} %{buildroot}%{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion}

# install the bash completion
install -d -m 0755 %{buildroot}%{_datadir}/bash-completion/completions/
%{buildroot}%{_bindir}/kubectl%{baseversion} completion bash > %{buildroot}%{_datadir}/bash-completion/completions/kubectl

# move CHANGELOG-%{baseversion}.md to old location
mv CHANGELOG/CHANGELOG-%{baseversion}.md .

# cleanup before copying dirs...
rm -f hack/.linted_packages
find .    -name '.gitignore' -type f -delete
find hack -name '*.sh.orig' -type f -delete
find hack -name '.golint_*' -type f -delete

# systemd service
install -d -m 0755 %{buildroot}%{_unitdir}
install -m 0644 -t %{buildroot}%{_unitdir}/ %{SOURCE10}

# make symlinks to rc files
install -d -m 0755 %{buildroot}%{_sbindir}
ln -sf service "%{buildroot}%{_sbindir}/rckubelet"

# install manpages
install -d %{buildroot}%{_mandir}/man1
install -p -m 644 docs/man/man1/* %{buildroot}%{_mandir}/man1

# create config folder
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}

# manifests file for the kubelet
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/manifests

# place kubernetes.tmp.conf to /usr/lib/tmpfiles.d/kubernetes.conf
install -d -m 0755 %{buildroot}%{_tmpfilesdir}
install -D -m 0644 %{SOURCE27} %{buildroot}/%{_tmpfilesdir}/kubelet.conf

# install the place the kubelet defaults to put volumes
install -d %{buildroot}%{_localstatedir}/lib/kubelet

%define volume_plugin_dir %{_localstatedir}/lib/kubelet/volume-plugin
install -d %{buildroot}/%{volume_plugin_dir}

# Add kubeadm modprobe.d and sysctl.d drop-in configs
mkdir -p %{buildroot}%{_prefix}/lib/modules-load.d
mkdir -p %{buildroot}%{_sysctldir}
install -m 0644 -t %{buildroot}%{_prefix}/lib/modules-load.d/ %{SOURCE23}
install -m 0644 -t %{buildroot}%{_sysctldir} %{SOURCE24}

# Create kubeadm systemd unit drop-in
install -d -m 0755 %{buildroot}%{_unitdir}/kubelet.service.d
sed -i -e 's|PATH_TO_FLEXVOLUME|%{volume_plugin_dir}|g' %{SOURCE25}
install -m 0644 -t %{buildroot}%{_unitdir}/kubelet.service.d/ %{SOURCE25}

# alternatives
ln -s -f %{_sysconfdir}/alternatives/kubectl %{buildroot}%{_bindir}/kubectl

%fdupes -s %{buildroot}

%post client-common
export baseversion="%{baseversion}"
%{_sbindir}/update-alternatives \
  --install %{_bindir}/kubectl kubectl %{_bindir}/kubectl%{baseversion} ${baseversion/./}

%postun client-common
if [ ! -f %{_bindir}/kubectl%{baseversion} ] ; then
  update-alternatives --remove kubectl %{_bindir}/kubectl%{baseversion}
fi

%pre kubelet-common
%service_add_pre kubelet.service

%post kubelet-common
%fillup_only -an kubelet
%service_add_post kubelet.service
%if 0%{?suse_version} < 1500
# create some subvolumes needed by CNI
if [ ! -e %{_localstatedir}/lib/cni ]; then
  if [ "`findmnt -o FSTYPE -l  /|grep -v FSTYPE`" = "btrfs" ]; then
    %{_sbindir}/mksubvolume %{_localstatedir}/lib/cni
  fi
fi
%endif
%tmpfiles_create %{_tmpfilesdir}/kubelet.conf

%preun kubelet-common
%service_del_preun kubelet.service

%postun kubelet-common
%service_del_postun kubelet.service

%files kubelet-common
%doc README.md CONTRIBUTING.md CHANGELOG-%{baseversion}.md
%license LICENSE
%{_mandir}/man1/kubelet.1%{?ext_man}
%{_bindir}/kubelet
%{_unitdir}/kubelet.service
%dir %{_unitdir}/kubelet.service.d
%{_sbindir}/rckubelet
%dir %{_localstatedir}/lib/kubelet
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/manifests
%{_tmpfilesdir}/kubelet.conf
%attr(0750,root,root) %dir %ghost %{_rundir}/%{name}
%dir %{volume_plugin_dir}
%{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion}

# openSUSE is using kubeadm with containerizied control plane, we
# only need the binaries

%files apiserver
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-apiserver.1%{?ext_man}
%{_bindir}/kube-apiserver

%files controller-manager
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-controller-manager.1%{?ext_man}
%{_bindir}/kube-controller-manager

%files scheduler
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-scheduler.1%{?ext_man}
%{_bindir}/kube-scheduler

%files proxy
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-proxy.1%{?ext_man}
%{_bindir}/kube-proxy

%files kubelet
%license LICENSE
%{_bindir}/kubelet%{baseversion}

%files kubeadm
%doc README.md CONTRIBUTING.md CHANGELOG-%{baseversion}.md
%{_unitdir}/kubelet.service.d/10-kubeadm.conf
%dir %{_prefix}/lib/modules-load.d
%{_prefix}/lib/modules-load.d/kubeadm.conf
%{_sysctldir}/90-kubeadm.conf
%license LICENSE
%{_bindir}/kubeadm
%{_mandir}/man1/kubeadm*

%files client
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_bindir}/kubectl
%{_bindir}/kubectl%{baseversion}
%ghost %_sysconfdir/alternatives/kubectl

%files client-common
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kubectl.1%{?ext_man}
%{_mandir}/man1/kubectl-*
%{_datadir}/bash-completion/completions/kubectl

%changelog
* Wed Oct 13 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Bump disk constraint to 10GB. The last successful builds
  currently occupy 9.4GB of disk space.
* Thu Sep 16 2021 rbrown@suse.com
- Update to version 1.19.15:
  * optimize the use of informer for scheduler
  * Initialize scheduler's podInformer in sharedInformerFactory
  * Fix buckets initialization
  * Do not throw error when we can't get canonical path
  * Fix vsphere disk detach failing
  * fix: ensure InstanceShutdownByProviderID return false for creating Azure VMs
  * fix: skip case sensitivity when checking Azure NSG rules
  * Add subpath mount files to BUILD
  * Pass additional flags to subpath mount to avoid flakes in certain conditions
  * Create a FakeMounter for the subpath that wraps the mountutils FakeMounter
  * Duplicate vendor/k8s.io/utils/mount/fake_mounter.go history in pkg/volume/util/subpath/subpath_fake_mounter.go history.
  * Add MountSensitiveWithFlags to the subpath Mounter interface
  * New subpath Mounter implements mount.Interface, update kubelet startup
  * Duplicate vendor/k8s.io/utils/mount/* history in pkg/volume/util/subpath/subpath_* history.
  * Update CHANGELOG/CHANGELOG-1.19.md for v1.19.14
  * Copy golang license to staging copies
  * job controller: don't mutate shared cache object
  * Set idle and readheader timeouts
* Wed Aug 25 2021 rbrown@suse.com
- Update to version 1.19.14:
  * Bump to golang 1.15.15 in build/**
  * Bump to golang 1.15.15 in cluster/** and staging/**
  * Bump to golang 1.15.15 in test/**
  * Avoid spurious calls to update/delete validation
  * update comments and owners file for pkg/util/removeall
  * kubelet: do not call RemoveAll on volumes directory for orphaned pods
  * Update CHANGELOG/CHANGELOG-1.19.md for v1.19.13
  * Add missing locks for device-manager in 1.19
  * test/e2e: Busybox image is not being templatized
  * Fix race in attachdetach tests
* Fri Jul 16 2021 rbrown@suse.com
- Update to version 1.19.13:
  * Bump to golang 1.15.14 in build/**
  * Bump to golang 1.15.14 in cluster/** and staging/**
  * Bump to golang 1.15.14 in test/**
  * Update debian-iptables image to buster-v1.6.5
  * Update debian-base image to buster-v1.8.0
  * Bump SMD to v4.1.2 to pick up #102749 fix
  * generate scheduler merge patches on the pod status instead of the full pod
  * Handle int -> float conversion in FromUnstructured
  * Fix Node Resources plugins score when there are pods with no requests
  * Update CHANGELOG/CHANGELOG-1.19.md for v1.19.12
  * Remove error wrap from logs
  * staging/publishing: Set default go version to go1.15.13
  * build: Update to k/repo-infra@v0.1.8 (supports go1.15.13)
  * Use go-runner:v2.3.1-go1.15.13-buster.0 image (built on go1.15.13)
  * Update to go1.15.13
  * Return UnschedulableAndUnresolvable when looking up volume-related resources returns NotFound error
  * Return UnschedulableAndUnresolvable instead of Error when failing to lookup pvc or storageclass in VolumeZone plugin
  * sched: fix a bug that a preemptor pod exists as a phantom
  * Revert "Cleanup portforward streams after their usage"
  * Fix VolumeAttachment garbage collection for migrated PVs
  * Ignore transient errors when gather stats
  * Speed up PV provisioning for vsphere driver
  * dependencies: update debian-base/debian-iptables regex
  * Update etcd image revision
  * Update debian-base to buster-v1.7.0
  * Update debian-iptables to buster-v1.6.1
  * Respect annotation size limit for SSA last-applied.
  * Fix expired unit test certs
  * fix: delete non existing disk issue
  * Azure: avoid setting cached Sku when updating VMSS and VMSS instances
  * Update cos-gpu-installer image
  * Ref counting is only applicable to Remote endpoints
  * Make watch order conformance test reliable
  * actually retry if we failed to reconcile some objects
  * Update CHANGELOG/CHANGELOG-1.19.md for v1.19.11
  * chunk target operatation for aws targetGroup
  * Use CSI driver to determine unique name for migrated in-tree plugins
  * staging/publishing: Set default go version to go1.15.12
  * build: Update to k/repo-infra@v0.1.7 (supports go1.15.12)
  * Use go-runner:v2.3.1-go1.15.12-buster.0 image (built on go1.15.12)
  * Update to go1.15.12
  * Avoid caching the VMSS instances whose network profile is nil
  * Fix watchForLockfileContention memory leak
  * Updating EndpointSlice controllers to avoid duplicate creations
  * Backport SIG Node approvers to 1.19
  * Update pkg/volume/azure_file/azure_provision.go
  * Normalize share name to not include capital letters
  * Extend pod start timeout to 5min for storage subpath configmap test
  * no watch endpointslice in userpace mode
  * Ensure service deleted when the Azure resource group has been deleted
  * Updating EndpointSlice validation to match Endpoints validation
  * Make parallel build memory threshold configurable
  * fix: azure file namespace issue in csi translation
  * pkg/kubelet: improve the node informer sync check
  * Additional CVE-2021-3121 fix
  * Fix startupProbe behaviour changed
  * Fix test
  * staging/publishing: Set default go version to go1.15.10
  * build: Update to k/repo-infra@v0.1.6 (supports go1.15.11)
  * Use go-runner:v2.3.1-go1.15.11-buster.0 image (built on go1.15.11)
  * Update to go1.15.11
  * add duration encoder to structured logger
  * Update CHANGELOG/CHANGELOG-1.19.md for v1.19.10
  * apf: exempt probes /healthz /livez /readyz
  * list pod list once to avoid timeout
  * Cleanup portforward streams after their usage
  * Fixed the Dockerfile for the build-image to build from KUBE_BASE_IMAGE_REGISTRY
* Thu Apr 15 2021 rbrown@suse.com
- Update to version 1.19.10:
  * azure: fix node public IP not able to fetch issues from IMDS
  * Add yaml util to unmarshal numbers into int/float
  * Use apply to create objects in TestApplyStatus
  * Stop skipping APIService in apply test
  * Stop clearing OpenAPIConfig for kube-aggregator
  * Add ability to skip OpenAPI handler installation
  * apf: fix test flake
  * Fixed describe ingress causing SEGFAULT
  * update gogo/protobuf to v1.3.2
  * Update sigs.k8s.io/structured-merge-diff to v4.0.3
  * e2e fix: loosen configmap to 10 in resource quota
  * apf: handle error from PollImmediateUntil
  * Stop probing a pod during graceful shutdown
  * staging/publishing: Set default go version to go1.15.10
  * build: Update to k/repo-infra@v0.1.5 (supports go1.15.10)
  * Use go-runner:v2.3.1-go1.15.10-buster.0 image (built on go1.15.10)
  * Update to go1.15.10
  * slice mirroring controller mirror annotations
  * webhook config manager: HasSynced returns true when the manager is synced with existing webhookconfig objects at startup
  * api-server add --lease-max-object-count
  * apiserver add metric etcd_lease_object_counts
  * update metadata-concealment to 1.6 for removing legacy checking
  * apiserver add --lease-reuse-duration-seconds to config lease reuse duration
  * additional subnet configuration for AWS ELB
  * Revert "Automated cherry pick of #97417: fix azure file secret not found issue"
  * Use the correct volum handle format for GCE regional PD.
  * Increasing maximum number of ports allowed in EndpointSlice
  * Update CHANGELOG/CHANGELOG-1.19.md for v1.19.9
  * bazel
  * deepcopy statefulsets
  * full deepcopy on munged pod spec
  * remove pod toleration toleration seconds mutation
  * add markers for inspected validation mutation hits
  * move secret mutation from validation to prepareforupdate
  * remove unnecessary mutations in validation
  * tweak validation to avoid mutation
  * For LoadBalancer Service type don't create a HNS policy for empty or invalid external loadbalancer IP
  * do not create StatefulSet pods when PVC is being deleted
  * AWS cloudprovider allow nlb-ip and external type lbs to be managed externally
* Wed Apr 14 2021 Richard Brown <rbrown@suse.com>
- Rebase opensuse-version-checks.patch
* Tue Apr 13 2021 rbrown@suse.com
- Update to version 1.19.9:
  * Updating EndpointSliceMirroring controller to wait for cache to be updated
  * Updating EndpointSlice controller to wait for cache to be updated
  * Add tests for populated volumes
  * Fix comment on getPodVolumeSubpathListFromDisk
  * Fix tests to test for new behavior
  * Add warnings after cleanup back
  * Automatically remove orphaned pod's dangling volumes
  * Count pod overhead as an entity's resource usage
  * Number of sockets is assumed to be same as NUMA nodes
  * Fix issue in checking domain socket for plugin watcher
  * Use Lstat in plugin watcher to avoid Windows problem
  * Skip visiting empty secret and configmap names
  * Fix test "[sig-windows] DNS should support configurable pod DNS servers"
  * move to cadvisor.MachineInfo
  * Avoid using socket for hints
  * Remove unnecessary snapshot ability check
  * Add linuxonly on one multivolume test
  * Mark some storage tests as LinuxOnly
  * Update topology tests for windows
  * Update storage test suits for Windows
  * Modify storage snapshottable and disruptive test for Windows
  * Separate in-tree gcepd driver for windows
  * Log PodExec stdout + stderr
  * e2e can't use both pod.Name and pod.GenerateName
  * Tolerate NotFound errors when deleting snapshots
  * tests: Refactors agnhost image pod usage in tests
  * Fix testpattern check
  * Combine switch case into one case
  * Ran hack/update-bazel.sh but discarded changes to root build file
  * Move common portion of dynamic snapshot out of switch statement
  * Remove custom hash function, generate a random UUID for snapshot and snapcontent name instead
  * Stack snapshot tests into one to reuse snapshot resource and reduce time taken on prow.
  * Quick commit
  * Remove snapshot class from prepv test because it is not needed.
  * Combine two tests with overlap to reduce overall snapshot test suite time
  * Add pre provisioned snapshot tests
  * Minor cleanup in snapshot test suite.
  * tests: Refactor agnhost image pod usage
  * Upgrading vendored dependencies
  * Upgrading cAdvisor to 0.37.5
  * Include unit test
  * Adjust defer to correctly call
  * do not remove volume dir when saveVolumeData fails
  * build/OWNERS: Add Dan and Sascha as reviewers
  * OWNERS(CHANGELOG): Move reviewers/approvers to CHANGELOG/ dir
  * Bump konnectivity-client to v0.0.15 in release-1.19
  * Storage e2e: Remove pd csi driver installation in GKE
  * Update CHANGELOG/CHANGELOG-1.19.md for v1.19.8
  * Use -LiteralPath instead of -Path
  * Escape the special character in vsphere windows path
  * kube-cross: update image to use v1.15.8-legacy-1
  * [go1.15] build: Update to k/repo-infra@v0.1.4 (supports go1.15.8)
  * Use go-runner:buster-v2.3.1 image (built on go1.15.8)
  * staging/publishing: Set default go version to go1.15.8
  * Update to go1.15.8
  * Cherry pick of #98254 for 1.19: Fix the kube-scheduler binary's description of the --config parameter is inaccurate
  * kubeadm: drop explicit constant override in version test
  * kubeadm: get k8s CI version markers from k8s infra bucket
  * Balance nodes in scheduling e2e
  * e2e: Pod should avoid nodes that have avoidPod annotation: clean remaining pods
  * fix kube-scheduler cannot send event because the Note field is too large
  * Fix nil pointer dereference in disruption controller
  * Fix translation of Cinder storage classess to CSI
  * Fix build after cherry-picking
  * Recover CSI volumes from dangling attachments
  * IsVolumeAttachedToNode() renamed to GetAttachState(), and returns 3 states instead of combining "uncertain" and "detached" into "false"
  * Fixes Attach Detach Controller reconciler race reading ActualStateOfWorld and operation pending states; fixes reconciler_test mock detach to account for multiple attaches on a node
  * Enable Volume Expansion tests for Windows
  * e2e/storage: disable caching when writing/reading to block PVCs
  * e2e: add option to create pods with different image in pod.Config
  * Remove file_mode args for Windows test
  * Set snapshotType for tests with NTFS.
  * make podTopologyHints protected by lock
  * Fix e2e autoscaling namespace error
  * Delete namespace parameter in create adapter
  * Deflake ingress updates
  * move all variables in sampleAndWaterMarkHistograms::innerSet
  * deferredResponseWriter returns after calling the Close() method
  * Fixed quantization and made monotic time reversal not panic
  * ignore cgroup driver check in windows node upgrade
  * OWNERS(CHANGELOG): Add 1.21 Release Notes shadows as reviewers
  * OWNERS(CHANGELOG): Add release-engineering-reviewers as approvers
  * OWNERS(CHANGELOG): Add wilsonehusin (1.21 relnotes lead) as approver
  * OWNERS(sig-release): Add CHANGELOG aliases
  * OWNERS(build-image): Add Release Managers as reviewers
  * OWNERS(releng): Sync Release Managers
  * OWNERS(sig-release): Remove SIG Release approvers alias
  * aggregate errors when putting vmss
  * fix azure file migration issue
  * kubelet: Fix mirrorPodTerminationMap leak
  * kubelet: Delete static pods gracefully
  * fix the remote endpoint cleanup logic
  * cleanup subnet in frontend ip configs
  * kubeadm: change the default image repository for CI images from gcr.io/kubernetes-ci-images to gcr.io/k8s-staging-ci-images
  * kubelet logs print 'kubelet nodes sync' frequently
  * handle webhook authenticator and authorizer error
  * Webhook: handle error when calling wait.ExponentialBackoff
  * Merge pull request #96876 from howieyuen/no-execute-taint-missing
  * vendor: update cAdvisor to v0.37.4
  * Use volumeHandle as PV name when translating EBS inline volume
  * Update CHANGELOG/CHANGELOG-1.19.md for v1.19.7
  * WIP: node sync at least once
  * clean up executing request on panic
  * fix the deadlock in priority and fairness config controller
  * kube-aggregator: fix apiservice availability gauge
  * Lower the frequency of volume plugin deprecation warning
* Wed Jan 20 2021 dmueller@suse.com
- Update to version 1.19.7:
  * use default unkown sock for kubeadm cmd if cri detect is not needed
  * cherry-pick part of #97451: fix nodeport quota check failure during creating clusterip
  * Release reserved GCE IP address after ensure completes.
  * Ensure reproducible builds when build through docker
  * Fix cadvisor machine metrics
  * Create OWNERS for most of the API Priority and Fairness impl
  * Fix bug in CPUManager with race on map acccess
  * fix azure file secret not found issue
  * fix: azure file latency issue for metadata-heavy workload
  * Update CHANGELOG/CHANGELOG-1.19.md for v1.19.6
  * Add more logging for Mount error
* Tue Jan  5 2021 rbrown@suse.com
- Update to version 1.19.6:
  * volumebinding: report UnschedulableAndUnresolvable status instead of an error when PVC not found
  * E2E stress test suite for VolumeSnapshots
  * [go1.15] Use go-runner:buster-v2.2.2 image (built on go1.15.5)
  * [go1.15] staging/publishing: Set default go version to go1.15.5
  * [go1.15] Update to go1.15.5
  * [go1.15] hack/tools: Update to k/repo-infra@v0.1.3 (supports go1.15.5)
  * [go1.15] build: Update to k/repo-infra@v0.1.3 (supports go1.15.5)
  * Flush FibreChannel devices before deleting
  * Fix FibreChannel volume plugin corrupting filesystem on detach
  * vendor: update cAdvisor to v0.37.3
  * Update CHANGELOG/CHANGELOG-1.19.md for v1.19.5
  * fix migration logic
  * Add AcceleratorStats to cri_stats_provider
  * coredns dep.Severity is newdefault, not newDefault
  * Update ingress conformance test for finalizers
  * bump cadvisor to 0.37.2
  * Restore beta os/arch labels on initial node registration
  * fix bug: concurrent map writes error
  * range_allocator: Test (lack of) double counting
  * cidrset: Add test for double counting
  * Fix double counting of IP addresses
  * Choosing the right source VIP for local endpoints
  * Bump node-problem-detector to v0.8.5
  * allow configuring ReadIdelTimeout and PingTimeout via env var
  * Add a unit test testing the HTTP/2 health check help the REST client detects broken TCP connections.
  * configure the ReadIdleTimeout and PingTimeout of the h2 transport
  * update golang.org/x/net and golang.org/x/sys, equivalent of #96549
  * fix: resize Azure disk issue when it's in attached state
  * Remove ready directory which created in empty volumeMounter setUp func
  * Updating to cadvisor v0.37.1
  * Fix cacheWatcher leak when time jump to the future and jump back
  * update e2e kubectl test
  * prune type in preserve-unknown-fields objects
  * apiextensions: prune array type without items in published OpenAPI
  * fix pull image error from multiple ACRs using azure managed identity
  * fix kube-proxy cleanup
  * change GetFullQualifiedPluginNameForVolume to distinuish different drivers
  * Fix a bug that DefaultPreemption plugin is disabled when using scheduler policy
  * Update CHANGELOG/CHANGELOG-1.19.md for v1.19.4
  * use patch instead of replace to test the dry-run option
  * Fix --dry-run invocation in kubectl e2e
  * Clean up remaining ns flag
  * Use namespace flag passed to RunKubectl* methods
  * Update max data disk count with new instance types
  * fix the panic when kubelet registers if a node object already exists with no Status.Capacity or Status.Allocatable
  * report UnschedulableAndUnresolvable status instead of an error when PVCs can't find bound persistent volumes
  * do not allow inflight watermark histograms to fall too far behind
  * Fix bug in JSON path parser where an error occurs when a range is empty
  * Build files
  * Allow priority to be set for kubelet process on Windows
  * DelegatingAuthorizationOptions: exposes and sets a default timeout for SubjectAccessReview client
  * Do not update managedFields timestamp when they don't change
  * Mask bearer token in logs when logLevel >= 9
* Fri Nov 13 2020 rbrown@suse.com
- Update to version 1.19.4:
  * Do not skip externalLB update if some nodes are not found.
  * Honor disabled LocalStorageCapacityIsolation in scheduling
  * Disable watchcache for events
  * Fix seccomp PSP docker/default annotation handling
  * Re-add the event recorder in the release test
  * Don't clear the cached resourcelock when errors occurs on updates
  * Add failing test showing release is not working properly
  * Add lease release tests in leader election
  * Generate complete leader election record to resolve leader election issues with LeaseLocks
  * Fix a bug that Pods with topologySpreadConstraints get scheduled to nodes without required labels
  * If we set SelectPolicy MinPolicySelect on scaleUp behavior or scaleDown behavior,Horizontal Pod Autoscaler doesn`t automatically scale the number of pods correctly
  * fix: add missing patch flag for kubeadm init phase control-plane
  * Update the PIP when it is not in the Succeeded provisioning state during the LB update.
  * Do not assume storageclass is still in-tree after csi migration
  * Fix `kubectl describe ingress` format
  * Fixes high CPU usage in kubectl drain
  * Ignore deleted pods.
  * Automated cherry pick of #94781: Don't attempt to detach an FC device if we don't know its name
  * add a local tlsTransportCache to available_controller
  * don't cache transports for incomparable configs
  * Fix fcpath
  * Update CHANGELOG/CHANGELOG-1.19.md for v1.19.3
  * fix upgrade test
  * fix azure disk data loss issue on Windows
  * fix azure disk attach failure for disk size bigger than 4TB
  * cloud node controller: handle empty providerID from getProviderID
  * Updating kube-proxy to trim space from loadBalancerSourceRanges
  * Don't create a new sandbox for pod with RestartPolicyOnFailure if all containers succeeded
* Thu Oct 15 2020 rbrown@suse.com
- Update to version 1.19.3:
  * Azure: fix node removal race condition on VMSS deletion
  * Fix reporting network_programming_latency metrics in kube-proxy
  * make download-or-bust compatible with both sha512/sha1
  * replace sha1 with sha512
  * avoid potential secret leaking while reading .dockercfg
  * Mask Ceph RBD adminSecrets in logs when logLevel >= 4
  * upgrade test for BoundServiceAccountTokenVolume
  * fix detach azure disk issue when vm not exist
  * vsphere: improve logging message on node cache refresh event
  * Fix UpdateSnapshot when Node is partially removed
  * kubeadm: make the CP join handling of kubeconfig similar to "init"
  * kubeadm: warn but do not error out on missing CA keys on CP join
  * Return the Kubernetes version which stopped serving deprecated APIs by default
  * fix: detach azure disk broken on Azure Stack
  * Ensuring EndpointSlices are recreated after Service recreation
  * Handle nil elements when sorting, instead of panicking
  * use more granular buckets for azure api calls
  * do not mutate endpoints in the apiserver
  * Remove HeadlessService label in endpoints controller before comparing
  * test: add unit-test for TranslateCSIPVToInTree.
  * fix azure file migration panic
  * kubeadm: relax the validation of kubeconfig server URLs
  * portforward: Fix UDP-only ports calculation
  * make kube::util::find-binary not dependent on bazel-out/ structure
  * output go_binary rule directly from go_binary_conditional_pure
  * hack/lib/util.sh: some bash cleanups
  * bazel: Replace --features with Starlark build settings flag
  * [go1.15] staging/publishing: Set default go version to go1.15.2
  * [go1.15] build: Use go-runner:buster-v2.0.1 (built using go1.15.1)
  * [go1.15] Update to go1.15.2
  * [go1.15] hack/tools: Update to k/repo-infra@v0.1.1 (supports go1.15.2)
  * [go1.15] build: Update to k/repo-infra@v0.1.1 (supports go1.15.2)
  * Update CHANGELOG/CHANGELOG-1.19.md for v1.19.2
  * count of etcd object should be limited to the specified resource
  * Track pods with required anti-affinity
  * Ensure getPrimaryInterfaceID not panic when network interfaces for Azure VMSS are null
  * Fix misusage of RLock in timeCache lru.Cache.Get()
  * support ipv6 in e2e policy tests
  * Allow 404 error on lb deletion in azure
  * fix: azure disk resize error if source does not exist
  * chore: add diskclient.Update interface
  * chore: add diskclient.ListByResourceGroup interface
* Wed Oct  7 2020 Dirk Mueller <dmueller@suse.com>
- use obsinfo again for commit id extraction, as this matches
  upstream's build commit id (just in case).
* Wed Oct  7 2020 Dirk Mueller <dmueller@suse.com>
- fix git commit determination (bsc#1177289)
* Thu Sep 17 2020 rbrown@suse.com
- Update to version 1.19.2:
  * Fix index out of range panic for kubectl alpha debug
  * kubectl describe pod: use ReportingController as an event source
  * Update CNI plugins to v0.8.7
  * Add roundtrip tests for metrics repo
  * Cleanup custom metrics conversion functions
  * Update CHANGELOG/CHANGELOG-1.19.md for v1.19.1
  * Sort list of formats for --logging-format description to make it deterministic
* Thu Sep 10 2020 rbrown@suse.com
- Update to version 1.19.1:
  * build/lib/release: Explicitly use '--platform' in building server images
  * build/common.sh: Remove extraneous reference to debian-base image
  * Update default etcd server to 3.4.13
  * kubeadm: remove the CoreDNS check for supported image digests
  * Update snapshot controller to use k8s.gcr.io
  * kubeadm: make the scheduler and KCM connect to local endpoint
  * Fixed reflector not recovering from "Too large resource version" errors with API servers 1.17.0-1.18.5
  * let panics propagate up when processLoop panic
  * kubeadm: Fix `upgrade plan` for air-gapped setups
  * Add impersonated user to system:authenticated group
  * cleanup: print warning message after timeout
  * Revert "cleanup: decrease log level from warn to v3"
  * cleanup: decrease log level from warn to v3
  * Remove duplicate nodeSelector
  * test(kubelet): add a regression test to verify kubelet would not panic
  * fix(kubelet): protect `containerCleanupInfos` from concurrent map writes
  * fix(azure): check error returned by scaleSet.getVMSS
  * Fix issue on skipTest in storage suits
  * Use NLB Subnet CIDRs instead of VPC CIDRs in updateInstanceSecurityGroupsForNLB
  * Add PR #89069 Action Required
  * Update CHANGELOG/CHANGELOG-1.19.md for v1.19.0
* Mon Sep  7 2020 Richard Brown <rbrown@suse.com>
- kubernetes%%{baseversion}-kubeadm now obsoletes kubernetes%%{baseversionminus1}-kubeadm
* Fri Aug 28 2020 Richard Brown <rbrown@suse.com>
- Introduce kubernetes$FOO-client-common package to make -client truely parralel installable
* Thu Aug 27 2020 rbrown@suse.com
- Update to version 1.19.0:
  * Updating EndpointSliceMirroring controller to listen for Service changes
  * test(kuberuntime): deflake TestRemoveContainer
  * build: Update to go-runner:buster-v2.0.0
  * build: Migrate go-runner image building to k/release
  * Reserve Static IP in Ingress test
  * Add rbac patch permissions for system:controller:glbc ingresses/status
  * Update json-patch to v4.9.0 tagged release
  * synchronize agnhost image / app version
  * track agnhost version in dependencies.yaml
  * Make sampleAndWaterMarkHistograms not fall very far behind
  * fix e2e test
  * etcd 3.4.12
  * Deflake TestServiceRegistryUpdateDryRun test
  * Fixing a flaky EndpointSliceMirroring integration test
  * Updating EndpointSlice controller to wait for all caches to be synced
  * Deflake TestSubresourcePatch
  * Speed up master reconciler tests
  * Remove flaky audit e2e test
  * Fix building with GOFLAGS=-v
  * Fix issue in evaluating symlink path for subpath
  * move ixdy to emeritus
  * move krzyzacy to emeritus
  * Fix bug for inconsistent lists served from etcd
  * publishing: Drop 'go' field from 'controller-manager' 'master' branch
  * publishing: Use go1.15.0 as default version
  * publishing: Use go1.13.15 for 1.18, 1.17, and 1.16 release branches
  * Refactor locks on registeredNodesLocks
  * fix(pluginwatcher): watch socket dir before traversing it
  * test(kubectl): deflake run_kubectl_apply_tests
  * upgrade rules_docker
  * Fix validation of ingress rules with wildcard host
  * Add missing changelog entries for v1.18.7
  * Add missing changelog entries for v1.17.10
  * Keep track of remaining pods when a node is deleted.
  * Remove direct accesses to cache's node map
  * CHANGELOG: Update directory for v1.18.8 release
  * [go115] Require go1.15 in build helper scripts
  * CHANGELOG: Update directory for v1.17.11 release
  * Add sigs for root folders
  * CHANGELOG: Update directory for v1.16.14 release
  * [go1.15] Update to go1.15
  * [go1.15] hack/tools: Update to k/repo-infra@v0.0.12 (supports go1.15.0)
  * [go1.15] build: Update to k/repo-infra@v0.0.12 (supports go1.15.0)
  * [e2e]Bind csi driver namespace to test namespace to avoid namespace collision
  * Promote spiffxp to build/ approver
  * Updating EndpointSlice controllers to return if error encountered
  * e2e storage: avoid flaky test failure when watch dies
  * Validate ingress TLS secretName in v1
  * e2e services wait for endpoint and endpoint slices
  * [Flaky test]kubectl log test never restart pod
  * cluster/images/etcd: Build etcd@3.4.9-3 using debian-base@v2.1.3
  * build: Update to debian-base@v2.1.3 and debian-iptables@v12.1.2
  * Updating EndpointSlice e2e tests to accept duplicate EndpointSlices
  * test(endpoints): deflake TestWatchHTTPTimeout
  * Sync cache before starting scheduler test
  * forget the pod when the reserve plugins fail
  * Update SMD to v4.0.1 and kube-openapi
  * Wait for mock CSI Driver bringup to perform e2e test
  * scheduler_perf: label nodes for pod affinity
  * Skip LB test per schedulable node count
  * fix(azure): set default value of VmssVirtualMachinesCacheTTLInSeconds during init to prevent data race
  * [go1.15] Update to go1.15rc2
  * generated: hack/update-hack-tools.sh && hack/update-vendor.sh
  * [go1.15] hack/tools: Update to k/repo-infra@v0.0.11 (supports go1.15rc2)
  * [go1.15] build: Update to k/repo-infra@v0.0.11 (supports go1.15rc2)
  * Sign up dims for additional review roles
  * Update to json-patch 4.8.0
  * Deflake LimitRange e2e test
  * Add test cluster check when starting csi proxy
  * [go1.15] Use errors.As to unwrap net errors
  * Fix namespace controller cleanup orphaning
  * Add LabelSelector validation in Pod Affinity/AntiAffinity Filter and Score plugins
  * Add tests for out of band attachments
  * Add missing termination metrics to priority-and-fairness handler
  * e2e delete namespaces after finish
  * Add missing ppc64le architecture in the get-kube* scripts
  * Requeue service after endpoint deletion
  * Do not evict pods which tolerate all NoExecute taints
  * fix: deflake run_kubectl_apply_tests
  * Deflake TestUpdateNodeStatusWithLease - guard cached machineInfo
  * CHANGELOG: Update directory for v1.19.0-rc.4 release
  * Update CHANGELOG/CHANGELOG-1.19.md for v1.19.0-rc.4
  * Fix /readyz to contain informer-sync
  * Move bgrant0607 to emeritus status.
  * Update e2e csi images to k8s.gcr.io
  * Deflake scheduler PostBind integration test
  * cloud-node-lifecycle controller: add missing instancev2 calls for node exists and node shutdown
  * cloud provider: remove redundant implementation of InstanceMetadataByProviderID since instanceV2 is disabled for all providers
  * cloud provider: remove provider ID references and improve documentation
  * test/e2e: fail test rather than flooding logs if PVC watch is closed prematurely
  * fix TestVolumeBinding unit test
  * Deflake TestExpectationsOnRecreate
  * Add kind/regression label to the pull request template
  * Update Cluster Autoscaler version to 1.19.0
  * Make AttachDisk idempotent again
  * integration: Wait for PV to be available
  * Fixing memory leak in EndpointSliceMirroring EndpointSlice tracker
  * Fix an issue when rotated logs of dead containers are not removed.
  * Remove unuseful error message about updating pod conditions not owned by kubelet
  * Makefile: update test-e2e-node help
* Wed Aug 26 2020 Richard Brown <rbrown@suse.com>
- Initial Packaging
